CompositorSurfaceKind

Enum CompositorSurfaceKind 

pub enum CompositorSurfaceKind {
    Blit,
    Underlay,
    Overlay,
}
Which method is being used to draw a requested compositor surface

Variants



Blit

Don’t create a native compositor surface, blit it as a regular primitive



Underlay

Create a native surface, draw it under content (must be opaque)



Overlay

Create a native surface, draw it between sub-slices (supports transparent)

Implementations

Source

impl CompositorSurfaceKind

fn needs_cutout(&self) -> bool

Returns true if the type of compositor surface needs an alpha cutout rendered

Source

impl CompositorSurfaceKind

pub fn is_composited(&self) -> bool

Source

impl CompositorSurfaceKind

fn supports_segments(&self) -> bool

Returns true if the compositor surface strategy supports segment rendering