pub struct ExternalSurfaceDescriptor {Show 13 fields
pub local_surface_size: LayoutSize,
pub local_rect: PictureRect,
pub local_clip_rect: PictureRect,
pub clip_rect: DeviceRect,
pub transform_index: CompositorTransformIndex,
pub compositor_clip_index: Option<CompositorClipIndex>,
pub image_rendering: ImageRendering,
pub z_id: ZBufferId,
pub dependency: ExternalSurfaceDependency,
pub native_surface_id: Option<NativeSurfaceId>,
pub update_params: Option<DeviceIntSize>,
pub external_image_id: Option<ExternalImageId>,
pub prim_instance_index: PrimitiveInstanceIndex,
}Expand description
Describes information about drawing a primitive as a compositor surface. For now, we support only YUV images as compositor surfaces, but in future this will also support RGBA images.
Fields
local_surface_size: LayoutSizelocal_rect: PictureRectlocal_clip_rect: PictureRectclip_rect: DeviceRecttransform_index: CompositorTransformIndexcompositor_clip_index: Option<CompositorClipIndex>image_rendering: ImageRenderingz_id: ZBufferIddependency: ExternalSurfaceDependencynative_surface_id: Option<NativeSurfaceId>If native compositing is enabled, the native compositor surface handle. Otherwise, this will be None
update_params: Option<DeviceIntSize>If the native surface needs to be updated, this will contain the size of the native surface as Some(size). If not dirty, this is None.
external_image_id: Option<ExternalImageId>If using external compositing, a user key for the client
prim_instance_index: PrimitiveInstanceIndexImplementations
Sourceimpl ExternalSurfaceDescriptor
impl ExternalSurfaceDescriptor
Sourcepub fn get_occluder_rect(
&self,
local_clip_rect: &PictureRect,
map_pic_to_world: &SpaceMapper<PicturePixel, WorldPixel>,
) -> Option<WorldRect>
pub fn get_occluder_rect( &self, local_clip_rect: &PictureRect, map_pic_to_world: &SpaceMapper<PicturePixel, WorldPixel>, ) -> Option<WorldRect>
Calculate an optional occlusion rect for a given compositor surface